# collibra-catalog_sampling_100
<p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import collibra_catalog_sampling 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import collibra_catalog_sampling
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import collibra_catalog_sampling
from collibra_catalog_sampling.rest import ApiException
from pprint import pprint
# Configure HTTP basic authorization: basicAuth
configuration = collibra_catalog_sampling.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = collibra_catalog_sampling.SamplesApi(collibra_catalog_sampling.ApiClient(configuration))
asset_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | Asset identifier
column_limit = 0 # int | The maximum number of columns to retrieve. If not set (columnLimit = <code>0</code>), the default column limit will be used. Maximum is set to 1500. (optional) (default to 0)
column_offset = 0 # int | The index of the fist column to retrieve. If not set (columnOffset = <code>0</code>), results will be retrieved starting from column <code>0</code>. (optional) (default to 0)

try:
    # Read sample data from the Collibra cloud repository or Edge cache
    api_response = api_instance.read_samples(asset_id, column_limit=column_limit, column_offset=column_offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SamplesApi->read_samples: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = collibra_catalog_sampling.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = collibra_catalog_sampling.SamplesApi(collibra_catalog_sampling.ApiClient(configuration))
asset_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | Asset identifier

try:
    # Create a request to collect and cache sample data for an Edge data source
    api_response = api_instance.request_samples(asset_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SamplesApi->request_samples: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */rest/catalogSampling/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SamplesApi* | [**read_samples**](docs/SamplesApi.md#read_samples) | **GET** /samples/{assetId} | Read sample data from the Collibra cloud repository or Edge cache
*SamplesApi* | [**request_samples**](docs/SamplesApi.md#request_samples) | **POST** /samples/{assetId}/request | Create a request to collect and cache sample data for an Edge data source

## Documentation For Models

 - [ColumnPagedResponse](docs/ColumnPagedResponse.md)
 - [Job](docs/Job.md)
 - [ReadSamplesResponse](docs/ReadSamplesResponse.md)
 - [RequestSamplesResponse](docs/RequestSamplesResponse.md)
 - [SampleColumn](docs/SampleColumn.md)
 - [StandardErrorResponse](docs/StandardErrorResponse.md)

## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## Author


